referrerpolicy=no-referrer-when-downgrade

NextPoolAssetId

Type Alias NextPoolAssetId 

pub type NextPoolAssetId<T: Config> = StorageValue<_GeneratedPrefixForStorageNextPoolAssetId<T>, T::PoolAssetId, OptionQuery>;
Stores the PoolAssetId that is going to be used for the next lp token. This gets incremented whenever a new lp pool is created.

Storage type is [StorageValue] with value type T :: PoolAssetId.

Aliased Type

pub struct NextPoolAssetId<T: Config>(/* private fields */);